#
# spec file for package asio
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           asio
Version:        1.11.0
Release:        5.4
Summary:        A cross-platform C++ library for network and low-level I/O programming
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Url:            http://asio.sourceforge.net/
Source0:        http://downloads.sourceforge.net/asio/asio-%{version}.tar.bz2
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  boost-devel
BuildRequires:  gcc-c++
BuildRequires:  libopenssl-devel
BuildRequires:  libtool
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Asio is a cross-platform C++ library for network and low-level I/O
programming that provides developers with a consistent asynchronous I/O
model using a modern C++ approach.

%package devel
Summary:        A cross-platform C++ library for network and low-level I/O programming
Group:          Development/Libraries/C and C++
Requires:       boost-devel
Requires:       openssl-devel

%description devel
Asio is a cross-platform C++ library for network and low-level I/O
programming that provides developers with a consistent asynchronous I/O
model using a modern C++ approach.

%prep
%setup -q
# Upstream generate them quite creatively, so refresh
autoreconf -fvi

%build
%configure
make %{?_smp_mflags}

%install
%make_install

%check
make check %{?_smp_mflags}

%files devel
%defattr(-,root,root,-)
%doc COPYING LICENSE_1_0.txt doc/*
%dir %{_includedir}/asio
%{_includedir}/asio/*
%{_includedir}/asio.hpp

%changelog
* Sat Mar 21 2015 mpluskal@suse.com
- Update to 1.11.0
  * Implemented changes to substantially reflect the Networking
    Library Proposal (N4370).
  * Added a new, executor-aware thread_pool class.
  * Changed spawn() to be executor-aware.
  * Added a new spawn() overload that takes only a function object.
  * Changed spawn() and yield_context to permit nested calls to
    the completion handler.
  * Removed previously deprecated functions.
  * Added options for disabling TLS v1.1 and v1.2.
  * Changed the SSL wrapper to call the password callback when
    loading an in-memory key.
  * Changed the tutorial to use std::endl to ensure output is flushed.
  * Fixed false SSL error reports by ensuring that the SSL error
    queue is cleared prior to each operation.
  * Fixed an ssl::stream<> bug that may result in spurious
    'short read' errors.
  * Enabled perfect forwarding for the first ssl::stream<>
    constructor argument.
  * Added standalone Asio support for Clang when used with
    libstdc++ and C++11.
  * Fixed an unsigned integer overflow reported by Clang's integer
    sanitizer.
  * Added support for move-only return types when using a
    yield_context object with asynchronous operations.
  * Ensured errors generated by Windows' ConnectEx function are
    mapped to their portable equivalents.
  * Changed multicast test to treat certain join_group failures
    as non-fatal.
- Remove no longer needed asio-no-multicast-test.patch
* Sun Dec 21 2014 wr@rosenauer.org
- remove multicast check from testsuite as it's failing in OBS
  (asio-no-multicast-test.patch)
* Fri Dec  5 2014 tchvatal@suse.com
- Enable testsuite
- Version bump to 1.10.4:
  * for full list of changes please visit
    http://think-async.com/Asio/asio-1.10.4/doc/asio/history.html#asio.history.asio_1_10_4
* Tue Jul 29 2014 wr@rosenauer.org
- Update to stable version 1.10.2
  * for full list of changes please visit
    http://think-async.com/Asio/asio-1.10.2/doc/asio/history.html#asio.history.asio_1_10_2
* Sun Mar 16 2014 wr@rosenauer.org
- Update to stable version 1.10.1
  * many changes as outlined here
    http://think-async.com/Asio/asio-1.10.1/doc/asio/history.html#asio.history.asio_1_10_1
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Add missing make call
- Use %%_smp_mflags for parallel build
* Thu Jun 23 2011 vlado.paskov@gmail.com
- Update to version 1.5.3
  * Added a new, completely rewritten SSL implementation. The new
    implementation compiles faster, shows substantially improved
    performance, and supports custom memory allocation and handler
    invocation. It includes new API features such as certificate
    verification callbacks and has improved error reporting. The new
    implementation is source-compatible with the old for most uses.
    However, if necessary, the old implementation may still be used by
    defining `(BOOST_)ASIO_ENABLE_OLD_SSL`.
  * Added new `asio::buffer()` overloads for `std::array`, when
    available. The support is automatically enabled when compiling in
  - std=c++0x mode on g++ 4.3 or higher, or when using MSVC 10.
    The support may be explicitly enabled by defining
    `(BOOST_)ASIO_HAS_STD_ARRAY`, or disabled by defining
    `(BOOST_)ASIO_DISABLE_STD_ARRAY`
  * Changed to use the C++0x standard library templates `array`,
    `shared_ptr`, `weak_ptr` and `atomic` when they are available,
    rather than the Boost equivalents.
  * Support for `std::error_code` and `std::system_error` is no longer
    enabled by default for g++ 4.5, as that compiler's standard
    library does not implement `std::system_error::what()` correctly.
* Fri May 22 2009 vuntz@novell.com
- Update to version 1.4.1. There's no NEWS/ChangeLog, but the 1.3
  development cycle brought those new features:
  + Enhanced CompletionCondition concept.
  + Wrapper class for Windows overlapped I/O.
  + Eventfd support on Linux.
  + Const overloads of lowest_layer().
  + Thread-safe synchronous socket operations.
  + Lazy initialisation of the io_service reactor task.
  + Bounds checking in ip::address_v4 and ip::address_v6.
- Drop asio-gcc43.patch: fixed upstream.
* Tue Apr 28 2009 ro@suse.de
- fix build (add missing includes)
* Wed Jan 14 2009 hfiguiere@suse.de
- Update to 1.2.0
  * Support for UNIX domain sockets.
  * Wrapper classes for POSIX stream-oriented file descriptors.
  * Reactor-style ready-to-read/write operations.
  * Add the ability to disable uses of the typeid keyword in asio by
    defining BOOST_NO_TYPEID or (BOOST_)ASIO_NO_TYPEID.
  * Add a new "porthopper" example illustrating mixed synchronous and
    asynchronous operations, and how to use Boost.Lambda with asio.
  * Rework the "invocation" example to better show how handler
    invocation hooks can be used with a variety of asynchronous
    operations.
  * Improved efficiency of basic_streambuf::consume()
  * Fixed infinite recursion in ssl::stream's shutdown()
  * Fixed a memory leak in use_tmp_dh_file().
  * Fixed a tight spin on epoll (or /dev/poll) that occurs when both
    EPOLLERR and EPOLLHUP events are reported for a descriptor and there
    are no pending operations.
  * Included CREAD and CLOCAL in the default flags for serial ports.
  * Various documentation improvements.
* Mon Aug 11 2008 ro@suse.de
- do not redefine debug_package
- use nodebuginfo instead and set debuginfo to no in PDB
* Sat Apr  5 2008 hfiguiere@suse.de
- Initial checkin
